@@ -226,7 +226,7 @@
  *
  * Sometimes you'll need to seek to a temporal offset in seconds into
  * a CMML file. Note: The seconds offset is calculated with respect to
- * the timebase attribute of the stream tag. libcmml provides an API
+ * the basetime attribute of the stream tag. libcmml provides an API
  * for this functionality through the cmml_skip_to_secs() function.
  *
  * The procedure is illustrated in cmml-seek-offset.c, which seeks to
@@ -241,7 +241,7 @@
  *
  * Sometimes you'll need to seek to a temporal offset in utc into a
  * CMML file. Note: The utc offset is calculated with respect to the
- * utc and timebase attributes of the stream tag. libcmml provides an
+ * utc and basetime attributes of the stream tag. libcmml provides an
  * API for this functionality through the cmml_skip_to_utc()
  * function.
  *
@@ -348,16 +348,16 @@
  * stream tag refer to the OUTPUT annodex media document for which
  * this CMML file provides the markup.
  *
- * \subsection tb Timebase attribute 
+ * \subsection tb Basetime attribute 
  *
- * The timebase attribute maps the first frame of the OUTPUT annodex
+ * The basetime attribute maps the first frame of the OUTPUT annodex
  * document to a playback time to be displayed with the first
  * frame. This playback time can be given as npt or some smpte
  * specification given as a name-value pair, and it defaults to 0.
  *
  * \subsection utc Utc attribute
  *
- * The optional utc attribute maps the timebase to a real-world clock
+ * The optional utc attribute maps the basetime to a real-world clock
  * time. It is given as a utc value.
  *
  * \subsection start Start attribute of source tags 
@@ -366,8 +366,8 @@
  * INPUT document into the Annodex media file, i.e. the absolute time
  * at which this media document (offset by seekoffset time) will start
  * within the OUTPUT Annodexed file. It will usually be given as a npt
- * or smpte time, which has to be greater than the timebase given in
- * the stream tag (or just greater than 0 if there is not timebase
+ * or smpte time, which has to be greater than the basetime given in
+ * the stream tag (or just greater than 0 if there is not basetime
  * given).  The value is given as a name-value pair separated by a
  * colon ":" though the name can be omitted if using npt. The start
  * attribute can also be given as a plain utc time, which has to be
@@ -464,10 +464,10 @@
  *
  * This is an example of such a specification:
 \verbatim
-<stream timebase="npt:0">
-  <source contenttype="video/x-theora" location="fish.ogg" start="npt:0"/>
-  <source contenttype="audio/x-vorbis" location="fishsound.ogg" start="npt:0"/>
-  <source contenttype="audio/x-speex" location="comments.spx" start="npt:7"/>
+<stream basetime="npt:0">
+  <import contenttype="video/x-theora" src="fish.ogg" start="npt:0"/>
+  <import contenttype="audio/x-vorbis" src="fishsound.ogg" start="npt:0"/>
+  <import contenttype="audio/x-speex" src="comments.spx" start="npt:7"/>
 </stream>
 \endverbatim
  *
