@@ -229,9 +229,9 @@ typedef struct {
   CMML_Time *end_time;   /**< end time of this clip */
   CMML_List * meta;      /**< list of meta elements */
   char *anchor_id;       /**< id attribute of anchor */
+  char *anchor_class;    /**< class attribute of clip */
   char *anchor_lang;     /**< language of anchor */
   char *anchor_dir;      /**< directionality of lang */
-  char *anchor_class;    /**< stylesheet of anchor */
   char *anchor_href;     /**< href out of clip */
   char *anchor_text;     /**< anchor text */
   char *img_id;          /**< id attribute of image */
@@ -239,7 +239,7 @@ typedef struct {
   char *img_dir;         /**< directionality of lang */
   char *img_src;         /**< keyframe image of clip */
   char *img_alt;         /**< alternate text for image */
-  char *desc_id;         /**< id attribute of desc element */
+  char *desc_id;         /**< id attribute of desc */
   char *desc_lang;       /**< language attribute of desc element */
   char *desc_dir;        /**< directionality of lang */
   char *desc_text;       /**< the description itself */
