@@ -91,7 +91,7 @@ cmml_preamble_new (char *encoding, char *id, char *lang, char *dir)
 CMML_Element *
 cmml_element_new(CMML_Element_Type type)
 {
-  CMML_Element * elem = cmml_malloc(sizeof(*elem));
+  CMML_Element * elem = cmml_malloc(sizeof(CMML_Element));
   
   switch (type) {
   case CMML_STREAM:
@@ -157,9 +157,9 @@ cmml_clip_new (CMML_Time *start_time, CMML_Time *end_time)
   a->end_time     = cmml_time_clone(end_time);
   a->meta         = cmml_list_new();
   a->anchor_id    = NULL;
+  a->anchor_class = NULL;
   a->anchor_lang  = NULL;
   a->anchor_dir   = NULL;
-  a->anchor_class = NULL;
   a->anchor_href  = NULL;
   a->anchor_text  = NULL;
   a->img_id       = NULL;
@@ -196,7 +196,7 @@ cmml_param_element_clone (CMML_ParamElement * param)
 
   if (param == NULL) return NULL;
 
-  new_param = (CMML_ParamElement* ) cmml_malloc (sizeof (CMML_ParamElement));
+  new_param = (CMML_ParamElement* ) cmml_malloc (sizeof(CMML_ParamElement));
   /* maybe consider memcpy for speedup and introduce reference counting!
      memcpy (new_param, param, sizeof (*new_param));
      -> NO: may introduce a problem with byte alignment
@@ -212,7 +212,7 @@ cmml_import_element_clone (CMML_ImportElement * import)
 {
   CMML_ImportElement * new_import;
   if (import == NULL) return NULL;
-  new_import = (CMML_ImportElement*) cmml_malloc (sizeof (CMML_ImportElement));
+  new_import = (CMML_ImportElement*) cmml_malloc (sizeof(CMML_ImportElement));
   new_import->id          = cmml_strdup (import->id);
   new_import->lang        = cmml_strdup (import->lang);
   new_import->dir         = cmml_strdup (import->dir);
@@ -235,7 +235,7 @@ cmml_meta_element_clone (CMML_MetaElement * meta)
 
   if (meta == NULL) return NULL;
 
-  new_meta = (CMML_MetaElement* ) cmml_malloc (sizeof (CMML_MetaElement));
+  new_meta = (CMML_MetaElement* ) cmml_malloc (sizeof(CMML_MetaElement));
   /* maybe consider memcpy for speedup and introduce reference counting!
      memcpy (new_meta, meta, sizeof (*new_meta));
   */
@@ -248,6 +248,7 @@ cmml_meta_element_clone (CMML_MetaElement * meta)
   return new_meta;
 }
 
+
 CMML_Preamble * 
 cmml_preamble_clone (CMML_Preamble * src)
 {
@@ -297,7 +298,7 @@ cmml_stream_clone(CMML_Stream * src)
 {
   CMML_Stream * s;
   if (src == NULL) return NULL;
-  s = (CMML_Stream *) cmml_malloc (sizeof (CMML_Stream));
+  s = (CMML_Stream *) cmml_malloc(sizeof(CMML_Stream));
   /*
   memcpy (s, src, sizeof (*s));
   */
@@ -319,7 +320,7 @@ cmml_head_clone(CMML_Head * head)
   CMML_Head * new_head;
 
   if (head == NULL) return NULL;
-  new_head = (CMML_Head *) cmml_malloc (sizeof (CMML_Head));
+  new_head = (CMML_Head *) cmml_malloc(sizeof(CMML_Head));
   /*
   memcpy (new_head, head, sizeof (*new_head));
   */
@@ -336,7 +337,6 @@ cmml_head_clone(CMML_Head * head)
   new_head->meta =
     cmml_list_clone_with (head->meta, (CMML_CloneFunc)cmml_meta_element_clone);
   return new_head;
-
 }
 
 CMML_Clip  * 
@@ -344,7 +344,7 @@ cmml_clip_clone (CMML_Clip * src)
 {
   CMML_Clip * a;
   if (src == NULL) return NULL;
-  a = (CMML_Clip *) cmml_malloc (sizeof (CMML_Clip));
+  a = (CMML_Clip *) cmml_malloc(sizeof(CMML_Clip));
   /*
   memcpy (a, src, sizeof (*a));
   */
@@ -357,9 +357,9 @@ cmml_clip_clone (CMML_Clip * src)
   a->meta =
     cmml_list_clone_with (src->meta, (CMML_CloneFunc)cmml_meta_element_clone);
   a->anchor_id       = cmml_strdup(src->anchor_id);
+  a->anchor_class    = cmml_strdup(src->anchor_class);
   a->anchor_lang     = cmml_strdup(src->anchor_lang);
   a->anchor_dir      = cmml_strdup(src->anchor_dir);
-  a->anchor_class    = cmml_strdup(src->anchor_class);
   a->anchor_href     = cmml_strdup(src->anchor_href);
   a->anchor_text     = cmml_strdup(src->anchor_text);
   a->img_id       = cmml_strdup(src->img_id);
@@ -502,16 +502,16 @@ cmml_clip_destroy(CMML_Clip * a)
 {
   if (a == NULL) return;
   cmml_free(a->clip_id);
-  cmml_free(a->track);
   cmml_free(a->lang);
   cmml_free(a->dir);
+  cmml_free(a->track);
   cmml_time_free(a->start_time);
   cmml_time_free(a->end_time);
   cmml_list_free_with(a->meta, (CMML_FreeFunc) cmml_meta_element_destroy);
   cmml_free(a->anchor_id);
+  cmml_free(a->anchor_class);
   cmml_free(a->anchor_lang);
   cmml_free(a->anchor_dir);
-  cmml_free(a->anchor_class);
   cmml_free(a->anchor_href);
   cmml_free(a->anchor_text);
   cmml_free(a->img_id);
@@ -652,6 +652,7 @@ int cmml_meta_list_snprint (char *buf, int *_len, int *_n, int *_n_written,
   return 0;
 }
 
+
 int
 cmml_preamble_snprint(char *buf, int n, CMML_Preamble *pre)
 {
@@ -897,9 +898,9 @@ int cmml_clip_snprint(char *buf, int n, CMML_Clip * a)
   if (a->anchor_id || a->anchor_text || a->anchor_href) {
     BEGIN_TAG("a");
     APPEND_ATTRIBUTE("id",    a->anchor_id);
+    APPEND_ATTRIBUTE("class", a->anchor_class);
     APPEND_ATTRIBUTE("lang",  a->anchor_lang);
     APPEND_ATTRIBUTE("dir",   a->anchor_dir);
-    APPEND_ATTRIBUTE("class", a->anchor_class);
     APPEND_ATTRIBUTE("href",  a->anchor_href);
     END_TAG();
     APPEND_DATA(a->anchor_text);
@@ -957,9 +958,9 @@ int cmml_clip_pretty_snprint(char *buf, int n, CMML_Clip * a)
   if (a->anchor_id || a->anchor_text || a->anchor_href) {
     BEGIN_TAG("a");
     APPEND_ATTRIBUTE("id", a->anchor_id);
+    APPEND_ATTRIBUTE("class", a->anchor_class);
     APPEND_ATTRIBUTE("lang", a->anchor_lang);
     APPEND_ATTRIBUTE("dir", a->anchor_dir);
-    APPEND_ATTRIBUTE("class", a->anchor_class);
     APPEND_ATTRIBUTE("href", a->anchor_href);
     END_TAG();
     APPEND_DATA(a->anchor_text);
