@@ -173,11 +173,12 @@ insert_stream_attrs(CMML_Stream * stream, const XML_Char **attr, CMML_Context *c
       }
     }
   }
-  /* set default timebase  */
+  /* adapt timebase */
   if (stream->timebase == NULL) {
+    /* default value */
     stream->timebase = cmml_time_new("0");
   }
-  /* check parsed timbase as it is used later in library */
+  /* check parsed timebase as it is used later in library */
   if (stream->timebase->t.sec < 0.0) {
     cmml_set_error((CMML*)ctxt, CMML_TIME_ERROR);
     return -1; /* stream to be destroyed */
@@ -195,7 +196,8 @@ insert_import_tag (CMML_List * import_list, const XML_Char **attr, CMML_Context
   int i;
   CMML_ImportElement * m;
 
-  if ((m = cmml_malloc(sizeof(*m))) == NULL) return import_list;
+  if ((m = (CMML_ImportElement *) cmml_malloc(sizeof(CMML_ImportElement))) 
+      == NULL) return import_list;
   m->id   = NULL;
   m->lang = NULL;
   m->dir  = NULL;
@@ -286,8 +288,10 @@ insert_param_tag(CMML_List * import_list, const XML_Char **attr,
   }
 
   /* create new param_element and insert it */
-  if((p = cmml_malloc(sizeof(*p))) == NULL) return import_list;
+  if((p = (CMML_ParamElement *) cmml_malloc(sizeof(CMML_ParamElement)))
+     == NULL) return import_list;
   p->id = NULL;
+  p->name = NULL;
   p->value = NULL;
   for (i = 0; attr[i] != NULL; i += 2) {
 #ifdef DEBUG
@@ -409,7 +413,8 @@ insert_meta_tag(CMML_List * meta_list, const XML_Char **attr, CMML_Context *ctxt
   int i;
   CMML_MetaElement * m;
 
-  if((m = cmml_malloc(sizeof(*m))) == NULL) return NULL;
+  if((m = (CMML_MetaElement *) cmml_malloc(sizeof(CMML_MetaElement)))
+     == NULL) return NULL;
   m->id = NULL;
   m->lang = NULL;
   m->dir = NULL;
@@ -446,6 +451,7 @@ insert_meta_tag(CMML_List * meta_list, const XML_Char **attr, CMML_Context *ctxt
   return meta_list;
 }
 
+
 /*
  * insert_clip_attrs: insert attributes from an "a" element into a
  * CMML_Element of type CMML_CLIP.
@@ -540,12 +546,12 @@ insert_anchor_attrs(CMML_Clip * clip, const XML_Char **attr, CMML_Context *ctxt)
 #endif
     if (cmml_strcmp(attr[i], "id") == 0) {
       clip->anchor_id = cmml_strdup(attr[i+1]);
+    } else if (cmml_strcmp(attr[i], "class") == 0) {
+      clip->anchor_class = cmml_strdup(attr[i+1]);
     } else if (cmml_strcmp(attr[i], "lang") == 0) {
       clip->anchor_lang = cmml_strdup(attr[i+1]);
     } else if (cmml_strcmp(attr[i], "dir") == 0) {
       clip->anchor_dir = cmml_strdup(attr[i+1]);
-    } else if (cmml_strcmp(attr[i], "class") == 0) {
-      clip->anchor_class = cmml_strdup(attr[i+1]);
     } else if (cmml_strcmp(attr[i], "href") == 0) {
       clip->anchor_href = cmml_strdup(attr[i+1]);
     }
@@ -655,8 +661,8 @@ cmml_xml_decl_parse (void *userData,
   context->status->info->xml_version  = cmml_strdup(version);
   context->status->info->xml_encoding = cmml_strdup(encoding);
   if (standalone < 0) {
-    /* set to "yes" by default */
-	context->status->info->xml_standalone = 1;
+    /* set to "no" by default */
+	context->status->info->xml_standalone = 0;
   } else {
 	context->status->info->xml_standalone = standalone;
   }
@@ -699,7 +705,7 @@ cmml_doctype_parse (void *userData,
  * attributes to that head.
  *
  * If the tag name is "desc" then assert that the currently processed 
- * CMML_Element is an clip, and add attributes to that clip.
+ * CMML_Element is a clip, and add attributes to that clip.
  *
  * If the tag name is "meta" then the CMML_Element at the tail of the
  * list can be either a head or an clip.
@@ -1221,7 +1227,7 @@ CMML_Context * cmml_context_setup (FILE * file)
 {
   /* allocate context */
   CMML_Context * context;
-  context = cmml_malloc(sizeof(CMML_Context));
+  context = (CMML_Context *) cmml_malloc(sizeof(CMML_Context));
 
   /* fill context fields */
   context->file = file;
@@ -1229,16 +1235,16 @@ CMML_Context * cmml_context_setup (FILE * file)
   context->parser = XML_ParserCreate(NULL); 
   XML_SetUserData(context->parser, context);
   context->sloppy_parsing = 0;
-  context->cdata = cmml_malloc(sizeof(CMML_DataBuf));
-  context->cdata->base = cmml_malloc(INIT_DATA_BUF_SIZE);
+  context->cdata = (CMML_DataBuf *) cmml_malloc(sizeof(CMML_DataBuf));
+  context->cdata->base = (XML_Char *) cmml_malloc(sizeof(XML_Char)*INIT_DATA_BUF_SIZE + 1);
   *(context->cdata->base) = '\0';
   context->cdata->limit = INIT_DATA_BUF_SIZE;
   context->read_stream = NULL;
   context->read_head   = NULL;
   context->read_clip = NULL;
   context->user_data = NULL;
-  context->status = cmml_malloc(sizeof(CMML_Status));
-  context->status->info = cmml_malloc(sizeof(CMML_Preamble));
+  context->status = (CMML_Status *) cmml_malloc(sizeof(CMML_Status));
+  context->status->info = (CMML_Preamble *) cmml_malloc(sizeof(CMML_Preamble));
   context->status->info->xml_version      = NULL;
   context->status->info->xml_encoding     = NULL;
   context->status->info->xml_standalone   = -2;
@@ -1335,7 +1341,7 @@ emalloc(size_t size)
 {
     void *p;
     
-    p = malloc(size);
+    p = calloc(1,size);
     if (!p) {
         fprintf(stderr, "libcmml: memory allocation error.");
         exit(1);
@@ -1396,7 +1402,7 @@ escape_chars (char *instr, int flag)
   }
 
   /* copy string changing characters */
-  retstr = cmml_malloc (len*sizeof(char)+1);
+  retstr = (char *) cmml_malloc (len*sizeof(char)+1);
   j=0;
   for (i=0,c=instr[0]; c!='\0'; c=instr[++i]) {
     switch (c) {
