@@ -64,19 +64,23 @@ parse_npt(const char *str)
   if (n == 3) {
     goto done;
   }
-  
+
+  /* this is not really according to spec, but we tolerate it */
   n = sscanf (str, "%d:%f",  &m, &s);
   if (n == 2) {
     h = 0;
     goto done;
   }
-
   n = sscanf (str, "%f", &s);
+
+  /* this gets activated even if there is more that just a float in
+     the string and thus is essentially always activated */
   if (n == 1) {
     h = 0; m = 0;
     goto sec_only;
   }
   
+  /* this only gets activated if there is no number in the string */
   return -1.0;
 
  done:
@@ -91,6 +95,119 @@ parse_npt(const char *str)
   return result;
 }
 
+/* fix_npt_str: INLINE function to parse and fix a npt-string */
+/* we don't generally muck around with the string that the user has provided */
+/* however, as we want to tolerate a npt spec without hours given */
+/* we have to do some fixing of the string */
+static char *
+fix_npt_str(const char *str)
+{
+  int h=0,m=0,n;
+  float s;
+  char * fixed_string;
+
+#ifdef DEBUG
+  fprintf(stderr,"fix_npt: %s\n", str);
+#endif
+
+  n = sscanf (str, "%d:%d:%f",  &h, &m, &s);
+  if (n == 3) {
+    goto pdone;
+  }
+
+  /* this is not really according to spec, but we tolerate it */
+  n = sscanf (str, "%d:%f",  &m, &s);
+  if (n == 2) {
+    h = 0;
+    goto pdone;
+  }
+
+  /* this gets activated even if there is more that just a float in
+     the string and thus is essentially always activated */
+  n = sscanf (str, "%f", &s);
+  if (n == 1) {
+    h = 0; m = 0;
+    goto psec_only;
+  }
+  
+  /* this only gets activated if there is no number in the string */
+  return NULL;
+
+ pdone:
+  /* check valid time specs */
+  if (h<0) return NULL;
+  if (m>59 || m<0) return NULL;
+  if (s>=60.0 || s<0.0) return NULL;
+
+  fixed_string = (char *) cmml_malloc (32);
+  /* %0 make leading 0s go away (zero padding) */
+  /* %2 provides a minimum field width */
+  /* %-1 makes left adjustment */
+  /* %. provides a thousands representation */
+  /* %.3 provides 3 numbers to appear after the dec point */
+  if (s < 10.0) {
+    sprintf (fixed_string, "%01d:%02d:0%2.3f", h, m, s);
+  } else {
+    sprintf (fixed_string, "%01d:%02d:%02.3f", h, m, s);
+  }
+  return fixed_string;
+
+ psec_only:
+  /* XXX fix this: calculate the length properly */
+  fixed_string = (char *) cmml_malloc (32);
+  sprintf (fixed_string, "%.3f", s);
+  return fixed_string;;
+}
+
+/* tstr_fix: INLINE function to parse a sec-string */
+/* and fix it, tolerating slighly off secifications of npt and smpte */
+char *
+cmml_tstr_fix (const char * str)
+{
+  char timespec[16];
+  char * fix_timespec = NULL;
+  char * full_timespec = NULL;
+  int speclen = 0;
+
+  if (str == NULL) {
+    return NULL;
+  }
+
+  if ((sscanf (str, "smpte-24:%16s", timespec) == 1) ||
+      (sscanf (str, "smpte-24-drop:%16s", timespec) == 1) ||
+      (sscanf (str, "smpte-25:%16s", timespec) == 1) ||
+      (sscanf (str, "smpte-30:%16s", timespec) == 1) ||
+      (sscanf (str, "smpte-30-drop:%16s", timespec) == 1) ||
+      (sscanf (str, "smpte-50:%16s", timespec) == 1) ||
+      (sscanf (str, "smpte-60:%16s", timespec) == 1) ||
+      (sscanf (str, "smpte-60-drop:%16s", timespec) == 1)) {
+    return (char *) str;
+  }
+
+  /* default is npt */
+  if (sscanf (str, "npt:%16s", timespec) == 1) {
+    speclen = 4;
+    fix_timespec = fix_npt_str (str+speclen);
+  } else {
+    speclen = 0;
+    fix_timespec = fix_npt_str (str);
+  }
+  if (fix_timespec == NULL) return NULL;
+  full_timespec = (char *) cmml_malloc(strlen(fix_timespec)+speclen+1);
+  if (speclen > 0) {
+    strncpy(full_timespec, "npt:", 4);
+  }
+  /* null-terminate the string */
+  full_timespec[speclen] = '\0';
+  /* append the time */
+  strcat(full_timespec, fix_timespec);
+#ifdef DEBUG
+  fprintf(stderr,"full_timespec  = %s\n", full_timespec);
+#endif
+
+  return full_timespec;
+}
+
 /* parse_smpte: INLINE function to parse a smpte-string */
 static double
 parse_smpte(const char *str, double framerate)
@@ -143,13 +260,14 @@ CMML_Time *
 cmml_sec_new (const char * s)
 {
   CMML_Time * t;
-  t = (CMML_Time *) cmml_malloc (sizeof (*t));
+  t = (CMML_Time *) cmml_malloc(sizeof(CMML_Time));
 
 #ifdef DEBUG
   fprintf(stderr, "creating new play time: %s\n", s);
 #endif
 
-  t->tstr = cmml_strdup(s);
+  /* XXX: fix copying of this string */
+  t->tstr = cmml_tstr_fix(s);
   t->type = CMML_SEC_TIME;
   t->t.sec = cmml_sec_parse(s);
 
@@ -161,7 +279,7 @@ CMML_Time *
 cmml_utc_new (const char * s)
 {
   CMML_Time * t;
-  t = (CMML_Time *) cmml_malloc (sizeof (*t));
+  t = (CMML_Time *) cmml_malloc(sizeof(CMML_Time));
 
 #ifdef DEBUG
   fprintf(stderr, "creating new utc time: %s\n", s);
@@ -245,7 +363,7 @@ cmml_time_interval_new (const char * s,
   } else {
     /* it's a time range */
     len_start_time = (int)(strlen(s) - strlen(pos));
-    start_time = (char *) cmml_malloc (len_start_time+1);
+    start_time = (char *) cmml_malloc(len_start_time+1);
     start_time = strncpy (start_time, s, len_start_time);
     start_time[len_start_time]='\0';
     *t_start = cmml_time_new(start_time);
@@ -275,7 +393,7 @@ cmml_time_interval_new (const char * s,
       } 
       /* create t_end for the smpte timecodes */
       if (seconds > 0) {
-	*t_end = (CMML_Time *) cmml_malloc (sizeof (CMML_Time));
+	*t_end = (CMML_Time *) cmml_malloc(sizeof(CMML_Time));
 	(*t_end)->tstr = cmml_strdup(pos+1);
 	(*t_end)->type = CMML_SEC_TIME;
 	(*t_end)->t.sec = seconds;
@@ -305,7 +423,7 @@ cmml_time_clone (CMML_Time * t1)
 {
   CMML_Time * t = NULL;
   if (t1 == NULL) return NULL;
-  t = (CMML_Time*) cmml_malloc (sizeof (CMML_Time));
+  t = (CMML_Time*) cmml_malloc(sizeof(CMML_Time));
   t->tstr = cmml_strdup(t1->tstr);
   t->type = t1->type;
   if (t->type == CMML_UTC_TIME) {
@@ -362,6 +480,7 @@ cmml_sec_parse (const char * str)
     return parse_smpte (str+14, 59.94);
   }
 
+  /* default is npt */
   return parse_npt(str);
 
 }
@@ -375,12 +494,12 @@ cmml_utc_parse (const char * s)
   int n;
   char tm_year[5], tm_month[3], tm_day[3], tm_hour[3], tm_min[3], tm_sec[3];
 
-  t = (CMML_UTC *) cmml_malloc (sizeof (*t));
+  t = (CMML_UTC *) cmml_malloc(sizeof(CMML_UTC));
 
   /* try parsing and return NULL in case of failure */
   n = sscanf (s, "%4s%2s%2s%*c%2s%2s%2s.%hi", tm_year, tm_month, tm_day, 
               tm_hour, tm_min, tm_sec, &(t->tm_hsec));
-#if 0
+#ifdef DEBUG
   if (n==6 || n==7) fprintf(stderr, "Successfully ");
   fprintf(stderr, "Parsed UTC time: %s\n", s);
   fprintf(stderr, "Year=%4s\tMonth=%2s\tDay=%2s\n", 
@@ -429,7 +548,7 @@ cmml_utc_clone (CMML_UTC * t1)
 {
   CMML_UTC * t;
   if (t1 == NULL) return NULL;
-  t = (CMML_UTC *) cmml_malloc (sizeof (*t));
+  t = (CMML_UTC *) cmml_malloc(sizeof(CMML_UTC));
   t->tm_hsec = t1->tm_hsec;
   t->tm_sec  = t1->tm_sec;
   t->tm_min  = t1->tm_min;
